TenantConfigStore

Struct TenantConfigStore 

pub struct TenantConfigStore { /* private fields */ }
Available on crate feature multi-tenant only.
Thread-safe tenant config store with strict tenant keying.

Examples

use http_handle::tenant_isolation::TenantConfigStore;
let _store = TenantConfigStore::default();
assert_eq!(1, 1);

Panics

This type does not panic.

Implementations

Source

impl TenantConfigStore

pub fn set_config( &self, tenant: TenantId, config: TenantConfig, ) -> Result<(), ServerError>

Writes tenant config snapshot.

Examples
use http_handle::tenant_isolation::{TenantConfig, TenantConfigStore, TenantId};
let store = TenantConfigStore::default();
let _ = store.set_config(TenantId("acme".into()), TenantConfig::default());
assert_eq!(1, 1);
Errors

Returns an error when the underlying lock is poisoned.

Panics

This function does not panic.

pub fn get_config( &self, tenant: &TenantId, ) -> Result<Option<TenantConfig>, ServerError>

Returns a cloned tenant config snapshot.

Examples
use http_handle::tenant_isolation::{TenantConfigStore, TenantId};
let store = TenantConfigStore::default();
let _ = store.get_config(&TenantId("acme".into()));
assert_eq!(1, 1);
Errors

Returns an error when the underlying lock is poisoned.

Panics

This function does not panic.